datashield.chisq.test: Runs Pearson's Chi-squared Test on non-pooled data

Description Usage Arguments Value Author(s) Examples

Description

Performs Pearson's Chi-squared Test for Count Data

Usage

1
  datashield.chisq.test(opals, a, b)

Arguments

a
b

Value

statistic: the value the chi-squared test statistic.

parameter: the degrees of freedom of the approximate chi-squared distribution of the test statistic

p.value: the p-value for the test.

method: a character string indicating the type of test performed, and whether Monte Carlo simulation or continuity correction was used.

data.name: a character string giving the name(s) of the data.

observed: the observed counts.

expected: the expected counts under the null hypothesis.

residuals: the Pearson residuals

stdres: standardized residuals

Author(s)

Gaye, A.

Examples

1
2
3
4
## Not run: 
# put example here

## End(Not run)

datashield/dsteststatsclient documentation built on May 14, 2019, 7:52 p.m.