Description Usage Arguments Details Value Author(s) Examples
Performs one and two sample t-tests on vectors of data.
1 2 3 | datashield.t.test(opals, x, y = NULL, alternative = 1,
mu = 0, paired = FALSE, var.equal = FALSE,
conf.level = 0.95)
|
opals |
character strings that represent the URL of the servers where the study datasets are stored. |
x |
a (non-empty) numeric vector of data values |
y |
an optional (non-empty) numeric vector of data values. |
alternative |
character string specifying the alternative hypothesis, must be one of "two.sided" (default), "greater" or "less". You can specify just the initial letter. |
mu |
a number indicating the true value of the mean (or difference in means if you are performing a two sample test). |
paired |
a logical indicating whether you want a paired t-test. |
var.equal |
a logical variable indicating whether to treat the two variances as being equal. If TRUE then the pooled variance is used to estimate the variance otherwise the Welch. (or Satterthwaite) approximation to the degrees of freedom is used. |
confidence |
level of the interval |
Summary statistics are obtained from each of the data sets that are located on the distinct computers/servers. And then grand means and variances are calculated. Those are used for performing t-test.
conf.level coefficients estimates of the parameters of the fitted model
a list containing the following elements:
the value of the t-statistic
parameter the degrees of freedom for the t-statistic
p.value the p-value for the test
conf.int a confidence interval for the mean appropriate to the specified alternative hypothesis
estimate the estimated mean or difference in means depending on whether it was a one-sample test or a two-sample test
null.value the specified hypothesized value of the mean or mean difference depending on whether it was a one-sample test or a two-sample test
alternative a character string describing the alternative hypothesis
method a character string indicating what type of t-test was performed
Isaeva J.
1 2 3 4 | ## Not run:
# put example here
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.